@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -59,7 +60,7 @@
 #include <docsh.hxx>
 #include <dbmgr.hxx>
 #include <uinums.hxx>
-#include <prtopt.hxx>		// fuer PrintOptions
+#include <prtopt.hxx>   // for PrintOptions
 #include <navicfg.hxx>
 #include <doc.hxx>
 #include <cmdid.h>
@@ -80,12 +81,9 @@ using namespace ::com::sun::star::view;
 using namespace ::com::sun::star::lang;
 
 
-/*-----------------08/28/97 08:41pm-----------------
-
---------------------------------------------------*/
 void lcl_SetUIPrefs(const SwViewOption* pPref, SwView* pView, ViewShell* pSh )
 {
-    // in FrameSets kann die tatsaechliche Sichtbarkeit von der Einstellung der ViewOptions abweichen
+    // in FrameSets the actual visibility can differ from the ViewOption's setting
     sal_Bool bVScrollChanged = pPref->IsViewVScrollBar() != pSh->GetViewOptions()->IsViewVScrollBar();
     sal_Bool bHScrollChanged = pPref->IsViewHScrollBar() != pSh->GetViewOptions()->IsViewHScrollBar();
     sal_Bool bVAlignChanged = pPref->IsVRulerRight() != pSh->GetViewOptions()->IsVRulerRight();
@@ -93,26 +91,26 @@ void lcl_SetUIPrefs(const SwViewOption* pPref, SwView* pView, ViewShell* pSh )
     pSh->SetUIOptions(*pPref);
     const SwViewOption* pNewPref = pSh->GetViewOptions();
 
-    // Scrollbars an / aus
+    // Scrollbars on / off
     if(bVScrollChanged)
     {
         pView->ShowVScrollbar(pNewPref->IsViewVScrollBar());
     }
     if(bHScrollChanged)
     {
-        pView->ShowHScrollbar( pNewPref->IsViewHScrollBar() || pSh->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE));
+        pView->ShowHScrollbar( pNewPref->IsViewHScrollBar() || pNewPref->getBrowseMode() );
     }
     //if only the position of the vertical ruler has been changed initiate an update
     if(bVAlignChanged && !bHScrollChanged && !bVScrollChanged)
         pView->InvalidateBorder();
 
-    // Lineale an / aus
+    // Rulers on / off
     if(pNewPref->IsViewVRuler())
         pView->CreateVLineal();
     else
         pView->KillVLineal();
 
-    // TabWindow an/aus
+    // TabWindow on / off
     if(pNewPref->IsViewHRuler())
         pView->CreateTab();
     else
@@ -121,11 +119,6 @@ void lcl_SetUIPrefs(const SwViewOption* pPref, SwView* pView, ViewShell* pSh )
     pView->GetPostItMgr()->PrepareView(true);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:	Aktuelle SwWrtShell
- --------------------------------------------------------------------*/
-
-
 SwWrtShell*	GetActiveWrtShell()
 {
     SwView *pActive = ::GetActiveView();
@@ -134,41 +127,31 @@ SwWrtShell*	GetActiveWrtShell()
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung: 	Pointer auf die aktuelle Sicht
- --------------------------------------------------------------------*/
-
-
 SwView* GetActiveView()
 {
     SfxViewShell* pView = SfxViewShell::Current();
     return PTR_CAST( SwView, pView );
 }
-/*--------------------------------------------------------------------
-    Beschreibung:	Ueber Views iterieren - static
- --------------------------------------------------------------------*/
 
 SwView* SwModule::GetFirstView()
 {
-    // liefert nur sichtbare SwViews
+    // returns only sivible SwView
     const TypeId aTypeId = TYPE(SwView);
     SwView* pView = (SwView*)SfxViewShell::GetFirst(&aTypeId);
     return pView;
 }
 
-
 SwView* SwModule::GetNextView(SwView* pView)
 {
-    DBG_ASSERT(PTR_CAST(SwView, pView),"keine SwView uebergeben");
+    OSL_ENSURE(PTR_CAST(SwView, pView),"return no SwView");
     const TypeId aTypeId = TYPE(SwView);
-    SwView* pNView = (SwView*)SfxViewShell::GetNext(*pView, &aTypeId, TRUE);
+    SwView* pNView = (SwView*)SfxViewShell::GetNext(*pView, &aTypeId, sal_True);
     return pNView;
 }
 
 /*------------------------------------------------------------------------
- Beschreibung:	Neuer Master fuer die Einstellungen wird gesetzt;
-                dieser wirkt sich auf die aktuelle Sicht und alle
-                folgenden aus.
+ Description:	New Master for the settings is set; this affects the
+                current view and all following.
 ------------------------------------------------------------------------*/
 
 void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
@@ -182,9 +165,9 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
                                          VIEWOPT_DEST_TEXT== nDest ? sal_False :
                                          pCurrView && pCurrView->ISA(SwWebView) ));
 
-    //per Uno soll nur die sdbcx::View, aber nicht das Module veraendert werden
+    // with Uno, only sdbcx::View, but not the Module should be changed
     sal_Bool bViewOnly = VIEWOPT_DEST_VIEW_ONLY == nDest;
-    //PreView abfruehstuecken
+    // fob PreView off
     SwPagePreView* pPPView;
     if( !pCurrView && 0 != (pPPView = PTR_CAST( SwPagePreView, SfxViewShell::Current())) )
     {
@@ -209,8 +192,13 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
     if( !pCurrView )
         return;
 
-    // Weitergabe an die CORE
-    const sal_Bool bReadonly = pCurrView->GetDocShell()->IsReadOnly();
+    // Passing on to CORE
+    sal_Bool bReadonly;
+    const SwDocShell* pDocSh = pCurrView->GetDocShell();
+    if (pDocSh)
+        bReadonly = pDocSh->IsReadOnly();
+    else //Use existing option if DocShell missing
+        bReadonly = pSh->GetViewOptions()->IsReadonly();
     SwViewOption* pViewOpt;
     if(!bViewOnly)
         pViewOpt = new SwViewOption( *pPref );
@@ -219,7 +207,7 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
     pViewOpt->SetReadonly( bReadonly );
     if( !(*pSh->GetViewOptions() == *pViewOpt) )
     {
-        //Ist evtl. nur eine ViewShell
+        //is maybe only a ViewShell
         pSh->StartAction();
         pSh->ApplyViewOptions( *pViewOpt );
         ((SwWrtShell*)pSh)->SetReadOnlyAvailable(pViewOpt->IsCursorInProtectedArea());
@@ -230,14 +218,13 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
 
     lcl_SetUIPrefs(pViewOpt, pCurrView, pSh);
 
-    // zum Schluss wird das Idle-Flag wieder gesetzt
-    // #42510#
+    // in the end the Idle-Flag is set again
     pPref->SetIdle(sal_True);
-}
-/* -----------------------------28.09.00 12:36--------------------------------
 
- ---------------------------------------------------------------------------*/
-void SwModule::ApplyUserMetric( FieldUnit eMetric, BOOL bWeb )
+    delete pViewOpt;
+}
+
+void SwModule::ApplyUserMetric( FieldUnit eMetric, sal_Bool bWeb )
 {
         SwMasterUsrPref* pPref;
         if(bWeb)
@@ -260,7 +247,7 @@ void SwModule::ApplyUserMetric( FieldUnit eMetric, BOOL bWeb )
         FieldUnit eVScrollMetric = pPref->IsVScrollMetric() ? pPref->GetVScrollMetric() : eMetric;
 
         SwView* pTmpView = SwModule::GetFirstView();
-        // fuer alle MDI-Fenster das Lineal umschalten
+        // switch the ruler for all MDI-Windows
         while(pTmpView)
         {
             if(bWeb == (0 != PTR_CAST(SwWebView, pTmpView)))
@@ -272,10 +259,8 @@ void SwModule::ApplyUserMetric( FieldUnit eMetric, BOOL bWeb )
             pTmpView = SwModule::GetNextView(pTmpView);
         }
 }
-/*-- 12.11.2008 14:47:58---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwModule::ApplyRulerMetric( FieldUnit eMetric, BOOL bHorizontal, BOOL bWeb )
+void SwModule::ApplyRulerMetric( FieldUnit eMetric, sal_Bool bHorizontal, sal_Bool bWeb )
 {
     SwMasterUsrPref* pPref;
     if(bWeb)
@@ -314,7 +299,7 @@ void SwModule::ApplyRulerMetric( FieldUnit eMetric, BOOL bHorizontal, BOOL bWeb
 set the usrpref 's char unit attribute and set ruler
 's unit as char if the "apply char unit" is checked
 --------------------------------------------------*/
-void SwModule::ApplyUserCharUnit(BOOL bApplyChar, BOOL bWeb)
+void SwModule::ApplyUserCharUnit(sal_Bool bApplyChar, sal_Bool bWeb)
 {
     SwMasterUsrPref* pPref;
     if(bWeb)
@@ -329,12 +314,12 @@ void SwModule::ApplyUserCharUnit(BOOL bApplyChar, BOOL bWeb)
         GetUsrPref(sal_False);
         pPref = pUsrPref;
     }
-    BOOL  bOldApplyCharUnit = pPref->IsApplyCharUnit();
-    BOOL    bHasChanged = FALSE;
+    sal_Bool bOldApplyCharUnit = pPref->IsApplyCharUnit();
+    sal_Bool bHasChanged = sal_False;
     if(bOldApplyCharUnit != bApplyChar)
     {
         pPref->SetApplyCharUnit(bApplyChar);
-        bHasChanged = TRUE;
+        bHasChanged = sal_True;
     }
 
     if( !bHasChanged )
@@ -360,7 +345,7 @@ void SwModule::ApplyUserCharUnit(BOOL bApplyChar, BOOL bWeb)
             eVScrollMetric = FUNIT_CM;
     }
     SwView* pTmpView = SwModule::GetFirstView();
-    // fuer alle MDI-Fenster das Lineal umschalten
+    // switch rulers for all MDI-Windows
     while(pTmpView)
     {
         if(bWeb == (0 != PTR_CAST(SwWebView, pTmpView)))
@@ -373,10 +358,6 @@ void SwModule::ApplyUserCharUnit(BOOL bApplyChar, BOOL bWeb)
     }
 }
 
-/*-----------------13.11.96 11.57-------------------
-
---------------------------------------------------*/
-
 SwNavigationConfig*  SwModule::GetNavigationConfig()
 {
     if(!pNavigationConfig)
@@ -386,27 +367,20 @@ SwNavigationConfig*  SwModule::GetNavigationConfig()
     return pNavigationConfig;
 }
 
-/*-----------------05.02.97 08.03-------------------
-
---------------------------------------------------*/
-
 SwPrintOptions* 	SwModule::GetPrtOptions(sal_Bool bWeb)
 {
     if(bWeb && !pWebPrtOpt)
     {
-        pWebPrtOpt = new SwPrintOptions(TRUE);
+        pWebPrtOpt = new SwPrintOptions(sal_True);
     }
     else if(!bWeb && !pPrtOpt)
     {
-        pPrtOpt = new SwPrintOptions(FALSE);
+        pPrtOpt = new SwPrintOptions(sal_False);
     }
 
     return bWeb ? pWebPrtOpt : pPrtOpt;
 }
 
-/*-----------------26.06.97 07.52-------------------
-
---------------------------------------------------*/
 SwChapterNumRules*	SwModule::GetChapterNumRules()
 {
     if(!pChapterNumRules)
@@ -414,17 +388,13 @@ SwChapterNumRules*	SwModule::GetChapterNumRules()
     return pChapterNumRules;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-void SwModule::ShowDBObj(SwView& rView, const SwDBData& rData, BOOL /*bOnlyIfAvailable*/)
+void SwModule::ShowDBObj(SwView& rView, const SwDBData& rData, sal_Bool /*bOnlyIfAvailable*/)
 {
     Reference<XFrame> xFrame = rView.GetViewFrame()->GetFrame().GetFrameInterface();
     Reference<XDispatchProvider> xDP(xFrame, uno::UNO_QUERY);
 
     uno::Reference<frame::XFrame> xBeamerFrame = xFrame->findFrame(
-                                        rtl::OUString::createFromAscii("_beamer"),
+                                        rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("_beamer")),
                                         FrameSearchFlag::CHILDREN);
     if (xBeamerFrame.is())
     {   // the beamer has been opened by the SfxViewFrame
@@ -440,13 +410,10 @@ void SwModule::ShowDBObj(SwView& rView, const SwDBData& rData, BOOL /*bOnlyIfAva
             xControllerSelection->select(makeAny(aSelection.createPropertyValueSequence()));
         }
         else {
-            DBG_ERROR("no selection supplier in the beamer!");
+            OSL_FAIL("no selection supplier in the beamer!");
         }
     }
 }
-/*--------------------------------------------------------------------
-    Beschreibung: Redlining
- --------------------------------------------------------------------*/
 
 sal_uInt16 SwModule::GetRedlineAuthor()
 {
@@ -461,13 +428,9 @@ sal_uInt16 SwModule::GetRedlineAuthor()
     return InsertRedlineAuthor( sActAuthor );
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 const String& SwModule::GetRedlineAuthor(sal_uInt16 nPos)
 {
-    DBG_ASSERT(nPos<pAuthorNames->Count(), "author not found!"); //#i45342# RTF doc with no author table caused reader to crash
+    OSL_ENSURE(nPos<pAuthorNames->Count(), "author not found!"); //#i45342# RTF doc with no author table caused reader to crash
     while (!(nPos<pAuthorNames->Count()))
     {
         InsertRedlineAuthor(String(RTL_CONSTASCII_USTRINGPARAM("nn")));
@@ -475,10 +438,6 @@ const String& SwModule::GetRedlineAuthor(sal_uInt16 nPos)
     return *pAuthorNames->GetObject(nPos);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 sal_uInt16 SwModule::InsertRedlineAuthor(const String& rAuthor)
 {
     sal_uInt16 nPos = 0;
@@ -492,10 +451,6 @@ sal_uInt16 SwModule::InsertRedlineAuthor(const String& rAuthor)
     return nPos;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void lcl_FillAuthorAttr( sal_uInt16 nAuthor, SfxItemSet &rSet,
                         const AuthorCharAttr &rAttr )
 {
@@ -508,8 +463,7 @@ void lcl_FillAuthorAttr( sal_uInt16 nAuthor, SfxItemSet &rSet,
          COL_AUTHOR4_DARK,		COL_AUTHOR5_DARK,	COL_AUTHOR6_DARK,
          COL_AUTHOR7_DARK,		COL_AUTHOR8_DARK,	COL_AUTHOR9_DARK };
 
-        aCol.SetColor( aColArr[ nAuthor % (sizeof( aColArr ) /
-                                           sizeof( aColArr[0] )) ] );
+        aCol.SetColor( aColArr[ nAuthor % (SAL_N_ELEMENTS(aColArr)) ] );
     }
 
     sal_Bool bBackGr = COL_NONE == rAttr.nColor;
@@ -563,26 +517,18 @@ void lcl_FillAuthorAttr( sal_uInt16 nAuthor, SfxItemSet &rSet,
         rSet.Put( SvxColorItem( aCol, RES_CHRATR_COLOR ) );
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwModule::GetInsertAuthorAttr(sal_uInt16 nAuthor, SfxItemSet &rSet)
 {
     lcl_FillAuthorAttr(nAuthor, rSet, pModuleConfig->GetInsertAuthorAttr());
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwModule::GetDeletedAuthorAttr(sal_uInt16 nAuthor, SfxItemSet &rSet)
 {
     lcl_FillAuthorAttr(nAuthor, rSet, pModuleConfig->GetDeletedAuthorAttr());
 }
 
 /*--------------------------------------------------------------------
-    Beschreibung: Fuer zukuenftige Erweiterung:
+    Description:	For future extension:
  --------------------------------------------------------------------*/
 
 void SwModule::GetFormatAuthorAttr( sal_uInt16 nAuthor, SfxItemSet &rSet )
@@ -590,19 +536,11 @@ void SwModule::GetFormatAuthorAttr( sal_uInt16 nAuthor, SfxItemSet &rSet )
     lcl_FillAuthorAttr( nAuthor, rSet, pModuleConfig->GetFormatAuthorAttr() );
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 sal_uInt16 SwModule::GetRedlineMarkPos()
 {
     return pModuleConfig->GetMarkAlignMode();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 sal_Bool SwModule::IsInsTblFormatNum(sal_Bool bHTML) const
 {
     return pModuleConfig->IsInsTblFormatNum(bHTML);
@@ -613,41 +551,27 @@ sal_Bool SwModule::IsInsTblChangeNumFormat(sal_Bool bHTML) const
     return pModuleConfig->IsInsTblChangeNumFormat(bHTML);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 sal_Bool SwModule::IsInsTblAlignNum(sal_Bool bHTML) const
 {
     return pModuleConfig->IsInsTblAlignNum(bHTML);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 const Color &SwModule::GetRedlineMarkColor()
 {
     return pModuleConfig->GetMarkAlignColor();
 }
 
-/*-----------------03.03.98 16:47-------------------
-
---------------------------------------------------*/
 const SwViewOption*	SwModule::GetViewOption(sal_Bool bWeb)
 {
     return GetUsrPref( bWeb );
 }
 
-// returne den definierten DocStat - WordDelimiter
 const String& SwModule::GetDocStatWordDelim() const
 {
     return pModuleConfig->GetWordDelimiter();
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
-// Durchreichen der Metric von der ModuleConfig (fuer HTML-Export)
+// Passing-through of the ModuleConfig's Metric (for HTML-Export)
 sal_uInt16 SwModule::GetMetric( sal_Bool bWeb ) const
 {
     SwMasterUsrPref* pPref;
@@ -665,46 +589,36 @@ sal_uInt16 SwModule::GetMetric( sal_Bool bWeb ) const
     }
     return static_cast< sal_uInt16 >(pPref->GetMetric());
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
-// Update-Stati durchreichen
+// Pass-through Update-Stati
 sal_uInt16 SwModule::GetLinkUpdMode( sal_Bool ) const
 {
     if(!pUsrPref)
         GetUsrPref(sal_False);
     return (sal_uInt16)pUsrPref->GetUpdateLinkMode();
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 SwFldUpdateFlags SwModule::GetFldUpdateFlags( sal_Bool ) const
 {
     if(!pUsrPref)
         GetUsrPref(sal_False);
     return pUsrPref->GetFldUpdateFlags();
 }
-/* -----------------------------28.09.00 14:18--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwModule::ApplyFldUpdateFlags(SwFldUpdateFlags eFldFlags)
 {
     if(!pUsrPref)
         GetUsrPref(sal_False);
     pUsrPref->SetFldUpdateFlags(eFldFlags);
 }
-/* -----------------------------28.09.00 14:18--------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwModule::ApplyLinkMode(sal_Int32 nNewLinkMode)
 {
     if(!pUsrPref)
         GetUsrPref(sal_False);
     pUsrPref->SetUpdateLinkMode(nNewLinkMode);
 }
-/* ---------------------------------------------------------------------------
 
- ---------------------------------------------------------------------------*/
 void SwModule::CheckSpellChanges( sal_Bool bOnlineSpelling,
         sal_Bool bIsSpellWrongAgain, sal_Bool bIsSpellAllAgain, sal_Bool bSmartTags )
 {
@@ -718,7 +632,7 @@ void SwModule::CheckSpellChanges( sal_Bool bOnlineSpelling,
              pDocSh = (SwDocShell*)SfxObjectShell::GetNext( *pDocSh, &aType ) )
         {
             SwDoc* pTmp = pDocSh->GetDoc();
-            if ( pTmp->GetRootFrm() )
+            if ( pTmp->GetCurrentViewShell() )	//swmod 071108//swmod 071225
             {
                 pTmp->SpellItAgainSam( bInvalid, bOnlyWrong, bSmartTags );
                 ViewShell* pViewShell = 0;
@@ -727,8 +641,6 @@ void SwModule::CheckSpellChanges( sal_Bool bOnlineSpelling,
                     pViewShell->GetWin()->Invalidate();
             }
         }
-//		pSpell->SetSpellWrongAgain( sal_False );
-//		pSpell->SetSpellAllAgain( sal_False );
     }
 }
 
@@ -738,3 +650,5 @@ void SwModule::ApplyDefaultPageMode(sal_Bool bIsSquaredPageMode)
         GetUsrPref(sal_False);
     pUsrPref->SetDefaultPageMode(bIsSquaredPageMode);
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
